{% load static %}
<aside class="drawer-side z-10">
  <label for="my-drawer" class="drawer-overlay"></label>
  <!-- sidebar menu -->
  <nav class="flex min-h-screen w-64 flex-col gap-2 overflow-y-auto bg-base-100 px-6 py-10">
    <div class="mx-4 flex items-center gap-2 font-black">
      <img src="{% static 'images/icon-logo.png' %}" alt="OctoIQ" class="h-10 w-15">
      <span>
        KitchenAI

      </span>
    </div>
    <ul class="menu">
      <li>
        <a href="{% url 'home' %}"
           class="{% if request.resolver_match.url_name == 'home' %}active{% endif %}">
          <svg data-src="https://unpkg.com/heroicons/20/solid/home.svg"
               class="h-5 w-5">
          </svg>
          Dashboard
        </a>
      </li>
    </ul>
  </nav>


</aside>
