{% extends "base.html" %}

{% block title %}
    Forbidden (403)
{% endblock title %}

{% block content %}
    <h1>Forbidden (403)</h1>
    <p>
        {% if exception %}
            {{ exception }}
        {% else %}
            You're not allowed to access this page.
        {% endif %}
    </p>
{% endblock content %}
