# Generated by Django 5.1.2 on 2024-11-29 21:24

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("core", "0005_notebook"),
    ]

    operations = [
        migrations.AddField(
            model_name="codefunction",
            name="notebook",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="core.notebook",
            ),
        ),
        migrations.AddField(
            model_name="codeimport",
            name="notebook",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="core.notebook",
            ),
        ),
        migrations.AddField(
            model_name="codesetup",
            name="notebook",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="core.notebook",
            ),
        ),
    ]
