<!-- header -->
<header class="col-span-12 flex items-center gap-2 lg:gap-4">
  <label for="my-drawer"
         class="btn btn-square btn-ghost drawer-button lg:hidden">
    <svg data-src="https://unpkg.com/heroicons/20/solid/bars-3.svg"
         class="h-5 w-5">
    </svg>
  </label>
  <div class="grow">
    <h1 class="lg:text-2xl lg:font-light">KitchenAI - Modular AI</h1>
  </div>
  {% comment %} <div>
    <input type="text" placeholder="Search" class="input input-sm rounded-full max-sm:w-24" />
  </div> {% endcomment %}
</header>
