# Generated by Django 5.1.2 on 2024-11-29 20:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("core", "0003_codefunction_label"),
    ]

    operations = [
        migrations.AlterField(
            model_name="codefunction",
            name="label",
            field=models.CharField(max_length=255),
        ),
    ]
