<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html lang="en-US">
    <head>
        <title>
            {% block title %}
                Base Email
            {% endblock title %}
        </title>
        <meta http-equiv="Content-Type" content="text/html;charset=UTF-8">
        <style type="text/css">
      td,
      p {
        font: normal 12px 'Helvetica Neue', Helvetica, Arial, sans-serif;
        color: #ababab;
      }

      a,
      a:visited {
        color: #0085cf;
        text-decoration: none;
      }

      a:hover {
        text-decoration: underline;
      }

      hr {
        border: none;
        border-bottom: 1px solid #b2b2b2;
      }
        </style>
    </head>
    <body {# djlint:off #}style="background-color:#e7e7e7"{# djlint:on #}>
        <table cellpadding="0"
            cellspacing="0"
            border="0"
            width="100%"
            align="center"
            {# djlint:off #}style="background-color:#e7e7e7"{# djlint:on #}>
            <tr>
                <td {# djlint:off #}style="padding: 40px;"{# djlint:on #}>
                    <table cellpadding="0"
                        cellspacing="0"
                        border="0"
                        width="705"
                        align="center"
                        {# djlint:off #}style="background-color:#ffffff"{# djlint:on #}>
                        <tr>
                            <td {# djlint:off #}
                  style="font: normal 12px 'Helvetica Neue', Helvetica, Arial, sans-serif;
                         color: #ababab"
                            {# djlint:on #}>
                            <div {# djlint:off #} style="padding: 20px;
                          border: 1px solid #b2b2b2;
                          -webkit-box-shadow: 0px 0px 4px #999;
                          -moz-box-shadow: 0px 0px 4px #999;
                          box-shadow: 0px 0px 4px #999;
                          -webkit-border-radius: 4px;
                          -moz-border-radius: 4px;
                            border-radius: 4px" {# djlint:on #}>
                            {% block email_content %}
                            {% endblock email_content %}
                        </div>
                    </td>
                </tr>
            </table>
        </td>
    </tr>
</table>
</body>
</html>
